@@ -19,7 +19,7 @@ use Exporter;
 use vars qw( $VERSION @ISA @EXPORT $err $errstr $drh $sqlstate );
 			# a couple of global variables that may come handy
 
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 $err = 0;
 $errstr = '';
@@ -284,9 +284,7 @@ sub execute {
 	# binded parameters
 	my $bind_values = $sth->{'xbase_bind_values'};
 
-	### the following code seems to somehow protect those "fixed"
-	### statements but I do not understand it at the moment
-	### if (defined $sth->{'xbase_lines'}) { return -1; }
+	if (defined $sth->{'xbase_lines'}) { return -1; }
 
 	# cancel the count of rows done in the previous run, this is a
 	# new execute
@@ -764,7 +762,7 @@ The memo fields will come out as nulls.
 
 =head1 VERSION
 
-1.04
+1.06
 
 =head1 AVAILABLE FROM
 
@@ -772,7 +770,7 @@ http://www.adelton.com/perl/DBD-XBase/
 
 =head1 AUTHOR
 
-(c) 1997--2013 Jan Pazdziora.
+(c) 1997--2016 Jan Pazdziora.
 
 Contact the author at jpx dash perl at adelton dot com.
 
